@@ -72,7 +72,8 @@
 #' p5 <- p + geom_hilight(data=dat, mapping=aes(node=id, fill=type), align="both")
 #' # display the high light layer with gradiental color rectangular.
 #' p6 <- p + geom_hilight(data=dat, mapping=aes(node=id, fill=type), type = "gradient", alpha=0.68)
-#' p7 <- p + geom_hilight(data=dat, mapping=aes(node=id, fill=type), type = "gradient", gradient.direction="tr", alpha=0.68)
+#' p7 <- p + geom_hilight(data=dat, mapping=aes(node=id, fill=type), 
+#'                       type = "gradient", gradient.direction="tr", alpha=0.68)
 #' # display the high light layer with round rectangular.
 #' p8 <- p + geom_hilight(data=dat, mapping=aes(node=id, fill=type), type = "roundrect", alpha=0.68)
 #' p2/ p3/ p4/ p5 / p6/ p7/ p8
@@ -452,10 +453,12 @@ get_clade_position_ <- function(data, node, reverse=FALSE) {
         xmin <- min(sp.df$branch, na.rm=TRUE)
         xmax <- max(x, na.rm=TRUE)
     }
+
+    w <- getOption("clade_width_extend", default = 0.5)
     data.frame(xmin=xmin,
                xmax=xmax,
-               ymin=min(y, na.rm=TRUE) - 0.5,
-               ymax=max(y, na.rm=TRUE) + 0.5)
+               ymin=min(y, na.rm=TRUE) - w,
+               ymax=max(y, na.rm=TRUE) + w)
 }
 
 build_align_data <- function(data, align){
@@ -482,8 +485,8 @@ build_align_data <- function(data, align){
 }
 
 
-#' @importFrom utils getFromNamespace
-rect_to_poly <- getFromNamespace("rect_to_poly", "ggplot2")
+
+
 
 ## ##' layer of hilight clade with rectangle
 ## ##'
@@ -624,3 +627,22 @@ rect_to_poly <- getFromNamespace("rect_to_poly", "ggplot2")
 ##                        required_aes = c("x", "y") #, "branch.length")
 ##                        )
 
+#' @importFrom utils getFromNamespace
+data_frame0 <- getFromNamespace("data_frame0", "ggplot2")
+
+
+# taken from ggplot2 as it was removed in recent release.
+# 
+# Convert rectangle to polygon
+# Useful for non-Cartesian coordinate systems where it's easy to work purely in
+# terms of locations, rather than locations and dimensions. Note that, though
+# `polygonGrob()` expects an open form, closed form is needed for correct
+# munching (c.f. https://github.com/tidyverse/ggplot2/issues/3037#issuecomment-458406857).
+#
+# @keyword internal
+rect_to_poly <- function(xmin, xmax, ymin, ymax) {
+  data_frame0(
+    y = c(ymax, ymax, ymin, ymin, ymax),
+    x = c(xmin, xmax, xmax, xmin, xmin)
+  )
+}
